% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualization.R
\name{plot_transformation_perturbation}
\alias{plot_transformation_perturbation}
\title{Plot transformation perturbation}
\usage{
plot_transformation_perturbation(audit_result)
}
\arguments{
\item{audit_result}{A shellgame_audit object}
}
\value{
A ggplot2 object
}
\description{
Creates a simple bar chart showing baseline vs recovered values.
}
