% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualization.R
\name{create_audit_report}
\alias{create_audit_report}
\title{Create complete audit report}
\usage{
create_audit_report(
  audit_result,
  zcta_baseline_sf = NULL,
  zcta_geometric_sf = NULL,
  county_sf = NULL
)
}
\arguments{
\item{audit_result}{A shellgame_audit object}

\item{zcta_baseline_sf}{Optional: SF object with baseline ZCTAs}

\item{zcta_geometric_sf}{Optional: SF object with geometric ZCTAs}

\item{county_sf}{Optional: SF object with county boundary}
}
\value{
List of ggplot2 objects
}
\description{
Generates all visualizations for an audit.
}
