% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_prep.R
\name{prep_zip_zcta}
\alias{prep_zip_zcta}
\title{Prepare ZIP-ZCTA crosswalk data}
\usage{
prep_zip_zcta(data, zip_col = NULL, zcta_col = "zcta")
}
\arguments{
\item{data}{Raw ZIP-ZCTA crosswalk data frame}

\item{zip_col}{Name of the ZIP code column (default: "ZIP_CODE" or "zip")}

\item{zcta_col}{Name of the ZCTA column (default: "zcta")}
}
\value{
Data frame with standardized columns: zcta, zip
}
\description{
Standardizes ZIP-ZCTA crosswalk data with proper column names and formatting.
}
\examples{
raw <- data.frame(ZIP_CODE = c("00010", "00010"), zcta = c("00001", "00002"))
result <- prep_zip_zcta(raw)
}
